<?php if (!defined('PLX_ROOT')) exit;

##############################################################################################
#
# plnStaticPages
# Auteur : Thomas # Date   : 22/06/2019 ··· 12/07/2020
# Auteur : Gari # Date   : 27/04/2015
#
# Ce plugin est un plugin TECHNIQUE. Il n'offre aucune fonctionnalité à un utilisateur de pluXml.
# Il est à destination des développeurs de plugin.
# Dès qu'un plugin veut une page statique, il peut utiliser plnStaticPages.
# Bien sur, cela entraine une dépendance et impose le téléchargement et l'installation de
# plnStaticPages pour utiliser le plugin.
#
# Le principe est de déclarer dans plnStaticPages l'ensemble des "fausses" pages statiques
# qu'on veut construire. Bien entendu, à tout moment seule une seule d'entre elle sera affichée.
#
# Les données à fournir :
# - trigger     : obligatoire : Le trigger d'URL pointant vers la page statique (du genre index.php?TRIGGER)
# - class       : obligatoire : La classe du plugin appelant
# - method      : facultatif  : Une fonction à appeler pour le corps de la page statique (au sens plxShow::staticContent())
# - pageTitle   : facultatif  : Titre de la page statique  (au sens plxShow::PageTitle())
# - staticTitle : facultatif  : Header de la page statique (au sens plxShow::staticTitle())
# - navLink     : facultatif  : Le titre du bouton "pages statiques", si vide alors pas de bouton
# - template    : facultatif  : template à utiliser
# - groupe      : facultatif  : groupe de la page (1.0.3)
#
# Ce plugin doit nécessairement être appelé EN DERNIER, après tous les plugins faisant appel à lui.
#
# La création du référentiel DOIT se faire avant la fin des hooks plxMotorPreChauffageBegin des plugins.
# Cette création DOIT embarquer au minimum le trigger qui permet de déclencher l'appel à la page statique.
# (appel minimum à la fonction plnMyStatiPages->newStaticPage($class,$trigger))
# On peut attendre avant de fournir les autres informations, ce qui permet par exemple de récupérer des
# informations complémentaire au fur-et-à-mesure du fonction du plugin, mais elles DOIVENT être fournies
# avant l'appel à plxShow.
#
# Si "method" n'est pas fourni, alors on tentera automatiquement de charger le fichier suivant :
# ../../plugins/<class>/<trigger>.<class>.php
#
# Exemple d'utilisateur à partir d'un plugin nommé PlugEx
#        $this->plxMotor   = plxMotor::getInstance();
#        $plnStaticPages = $this->plxMotor->plxPlugins->aPlugins["plnStaticPages"];
#        $plnStaticPages->newStaticPage("PlugEx","PlugExURL");
#        $plnStaticPages->setField("PlugExURL","staticTitle","Mon titre de page statique");
#        $plnStaticPages->setField("PlugExURL","method","displayPlugExContents");
#        $plnStaticPages->setField("PlugExURL","pageTitle","Mon zouli Titre de barre de navigateur");
#        $plnStaticPages->setField("PlugExURL","navLink","Mon Lien");
#        $plnStaticPages->setField("PlugExURL","template","static.php");
# Dans cet exemple, la fausse page statique sera affichée dès qu'on tentera d'accéder à la page
# index.php?PlugExURL
# Cet affichage se fera via la méthode :
# PlugEx::displayPlugExContents();
# Si jamais on ne renseignait pas la clé "method", alors ce serait le fichier suivant qui serait chargé :
# ../../plugins/PlugEx/PlugExURL.PlugEx.php
#
##############################################################################################

class plnStaticPages extends plxPlugin
{
    static $aPages;      // L'ensemble des informations des pages statiques
    static $currentPage; // La page à afficher, si elle existe
    static $getLang = '';  // Sur-dossier 'fr/', si plxMyMutilingue est présent

	##############################################################################################
	#
	# Le constructeur
	#
	##############################################################################################
	public function __construct($default_lang)
	{
		parent::__construct($default_lang);

        $this->addHook('plxMotorPreChauffageBegin','plxMotorPreChauffageBegin');
        $this->addHook('plxShowConstruct','plxShowConstruct');
        $this->addHook('plxShowPageTitle','plxShowPageTitle');
        # Le hook d'affichage du lien vers la page statique dans la liste "pages statiques" (navbar)
        $this->addHook('plxShowStaticListEnd', 'plxShowStaticListEnd');

        # On construit le tableau devant contenir l'ensemble des demandes de pages statiques
        self::$aPages       = array();
        self::$currentPage  = false;
	}

    ##############################################################################################
    #
    # On veut créer une nouvelle "fausse" pages statique
    # Si method n'est pas fourni au moment de l'appel plxShow, on tentera d'aller chercher un fichier
    # à l'endroit suivant :
    # ../../plugins/<class>/<trigger>.<class>.php
    #
    ##############################################################################################
    public static function newStaticPage($class,$trigger,$staticTitle='',$pageTitle='',$method='',$navLink='',$template='',$group='')
    {
        self::$aPages[$trigger] = array(
            'trigger'       => $trigger,    # tel que l'URL appelante est index.php?TRIGGER
            'class'         => $class,      # la classe du plugin qui appelle
            'method'        => $method,     # la méthode du plugin appelant permettant d'afficher le contenu (optionnel)
            'staticTitle'   => $staticTitle,# le titre de la page statique tel que défini dans le template
            'pageTitle'     => $pageTitle,  # le nom de la page (apparaitra dans la barre du navigateur)
            'navLink'       => $navLink,    # le nom du bouton apparaissant dans la navbar. Si vide, pas de bouton
            'template'      => $template,   # le template à appeler. Si vide, static.php
            'group'         => $group,      # le groupe de la page. Since 1.0.3
        );
    }

    ##############################################################################################
    #
    # A tout moment, on peut modifier un champ particulier d'une page existante en utilisant
    # cette méthode
    #
    ##############################################################################################
    public static function setField($trigger,$field,$value)
    {
        if(isset(self::$aPages[$trigger]))
            self::$aPages[$trigger][$field] = $value;
    }

    ##############################################################################################
    #
    # Le titre de la page
    #
    ##############################################################################################
    public function plxShowPageTitle()
    {
        if(self::$currentPage !== false and self::$aPages[self::$currentPage]['pageTitle'] != ''){
            echo '<?php ';?> echo '<?=self::$aPages[self::$currentPage]['pageTitle']?>';return true;
?><?php
        }
    }

    ##############################################################################################
    #
    # listing des pages statiques
    #
    ##############################################################################################
    public function plxShowStaticListEnd()
    {
        foreach(self::$aPages as $Page)
            if($Page['navLink'] != '')
            {
                echo '<?php '; ?>
                $stat = str_replace('#static_id','static-<?=$Page['trigger']?>',$format);
                $stat = str_replace('#static_class','static-menu static menu',$stat);
                $stat = str_replace('#static_url',$this->plxMotor->urlRewrite('?<?=self::$getLang.$Page['trigger']?>'),$stat);
                $stat = str_replace('#static_name','<?=preg_replace('~ ~','&nbsp;',$Page['navLink'])?>',$stat);
                if(preg_match('~^<?=$Page['trigger']?>~',$this->plxMotor->get))
                    $isActive='active';
                else
                    $isActive='noactive';
                $stat = str_replace('#static_status',$isActive,$stat);
                $menus[][] = $stat;
?><?php
            }
    }

    ##############################################################################################
    #
    # Juste avant l'affichage, on vérifie si ce n'est pas une page particulière qui est demandée
    #
    ##############################################################################################
    public function plxShowConstruct()
    {
        if(self::$currentPage === false) return;

        $Page      = self::$aPages[self::$currentPage];
        $readable  = 1;
        $base      = '../../'.rtrim(PLX_PLUGINS,'/');
        $cut       = 6;
        if(defined('PLX_MYMULTILINGUE'))
        {
            $base  = '../'.$base;
            $cut   = 9;
        }

        if($Page['method'] != '')
        {
            $cible = $base.'/plnStaticPages/dummy';
            $url   = 'plnStaticPages';
        }
        else
        {
            $cible = $base.'/'.$Page['class'].'/'.$Page['trigger'];
            $url   = $Page['class'];
        }
        if(!is_readable(substr($cible.'.'.$url.'.php',$cut)))
            $readable = 0;

        $template = $Page['template'] == '' ? 'static.php' : $Page['template'];

        echo '<?php '; ?>
        $this->plxMotor->cible = '<?=$cible?>';
        $this->plxMotor->template = '<?=$template?>';
        $array = array();
        $array[$this->plxMotor->cible] = array(
           'name'      => '<?=$Page['staticTitle']?>',
           'menu'      => '',
           'url'       => '<?=$url?>',
           'readable'  => <?=$readable?>,
           'active'    => 1,
           'group'     => '<?=$Page['group']?>'
        );
        $this->plxMotor->aStats = array_merge($this->plxMotor->aStats, $array);
?><?php
    }

    ##############################################################################################
    #
    # Lorsque le moteur est en train de préchauffer, on intercepte les demandes d'affichages
    # spécifiques.
    # On se base pour cela sur le trigger en "get", du genre index.php?TRIGGER
    #
    ##############################################################################################
    public function plxMotorPreChauffageBegin()
    {
        if(!isset($_GET) OR empty($_GET)) return;#not needed
        if(defined('PLX_MYMULTILINGUE')){#maybe global (on construct?)
            $lang = plxMyMultiLingue::_Lang();# Récupération de la langue en cours
            $get = array_keys($_GET);
            $get = empty($get)?'':$get[0];# Garde le 1er param
            if(!empty($lang))
              if(isset($_SESSION['default_lang']) AND $_SESSION['default_lang']!=$lang)
                self::$getLang = $lang . DIRECTORY_SEPARATOR;
              elseif(preg_match('~^'.$lang.'\/~',$get))#find ##/ 1er get
                self::$getLang = $lang . DIRECTORY_SEPARATOR;
              //~ elseif(preg_match('~^'.$lang.'\/~',plxUtils::getGets()))#find ##/ getGets
                //~ self::$getLang = $lang . DIRECTORY_SEPARATOR;
        }
        foreach(self::$aPages as $Num => $Page)
            if(isset( $_GET[ self::$getLang . $Page['trigger'] ] ))
            {
                self::$currentPage = $Num;
                $string="\$this->mode = '".$Page['trigger']."';return true;";
                echo "<?php ".$string." ?>";
                return;
            }
    }
}